% Matlab Mistuning Code: Version 1.0
%
% Created by: Benjamin Shapiro,
%             Control and Dynamical Systems
%             California Institute of Technology
%             Pasadena, CA 91125.
%             bshapiro@indra.caltech.edu
%
% *********************************************************
%
% File: show.m
% Purpose: Given a mistuning vector z, this file plots
%   (using an exact solution of the equations at z) the
%     1) mistuning z 
%     2) tuned vs mistuned eigenvalues
%     3) tuned vs mistuned bode plots
%     4) tuned vs mistuned response at `worst' frequency.
%   This file requires variables from Mistuning.m, run
%   that first. (I may change this to saved file later.)
% Last Update: 04/15/98 by B.Shapiro
%
% *********************************************************



% Pick mistuning y:

  % Modal mistuning:
    md = 3;
    sz = 0.01;
    y = sz * cos( (2*pi*md/r) * [1:1:r] );

% Write a comment ?
  comment = 'my comment';


% Initialize plots:
  figure(5);  % after first 4 ? of Mistuning.
  clf;


% Top left, mistuning z:
  subplot(2,2,1);
    plot(y,'ro-')
    title('Chosen mistuning pattern');
    xlabel('slot number');
    ylabel('mistuning');
      ymax = max(y);
      ymin = min(y);
      delta = ymax - ymin;
      ymax = ymax + delta/20;
      ymin = ymin - delta/20;
    axis([0 r+1 ymin ymax]);
% End top left.



% HEY, I CAN DO A CHECK BETWEEN 
% Error.m and Opt.m here. 
% Good: I now have the Error.m piece in
% show.m---they are equivalent on PW model.
% Error.m is slower but holds for any model.




  % Compute mistuned eigenvalues:
    % Construct M(y): (from Opt -> cost.m)
    zeta = 0.00032;
    for j = 0:r-1
      Mofy(j*d+1:(j+1)*d,:) = rot( MrowTun, r-j, d, r); % Tuned part.
        % Now modify by mistuning: elements (2,1) and (2,2).
          Mofy((j+1)*d,j*d+1) = Mofy((j+1)*d,j*d+1) ...
                              -2*y(j+1) -y(j+1)^2;
          Mofy((j+1)*d,j*d+2) = Mofy((j+1)*d,j*d+2) ...
                              -2*zeta*y(j+1);
    end
    % Got M(y).

    EigenMist = eig( Mofy );
  % Got mistuned eigenvalues.


% Top right, tuned vs mistuned eigenvalues:
  subplot(2,2,2);
    xmin = 1.25 * min( real( EigenTun ) );
    xmax = max( 0, max( real( EigenTun ) ) );
    ymax = max( imag( EigenTun ) );
    ymin = min( abs( imag( EigenTun ) ) );
    delta = ymax - ymin;
    ymax = ymax + delta/4;
    ymin = ymin - delta/4;
    plot( real(EigenTun), imag(EigenTun), 'b.', ... 
          real(EigenMist), imag(EigenMist), 'r+' )
    title('Tuned vs Mistuned Eigenvalues');
    axis([xmin xmax ymin ymax]);
    xlabel('real');
    ylabel('imag');







% Comments for entire plot:
  addinfo('', date, '', 'B. Shapiro, Caltech');

